@@ -37,7 +37,7 @@ function parseDate(year, baseDate, overrideDate, time)
 
 function parseLocation(place, addr1, addr2, links)
 {
-    if (!addr1)
+    if (!addr1 || addr1.startsWith(''))
         return;
     if (addr2)
         addr1 += ', ' + addr2;
@@ -63,7 +63,7 @@ function parsePdfTicket(pdf, node, triggerNode)
     let reservations = [];
     while (true) {
         const times = timeColumn.substr(idxTime).match(/(\d\d:\d\d)\n([^:]*?\n)?([^:]*?\n)?(\d\d:\d\d)/);
-        const stations = stationColumn.substr(idxStations).match(/(.*)\n[ ]+(.*)(?:\n|,\n  +(.*)\n)(?:.*(?:NOTE:|Wagennummerierung|platform).(?:.*\n)+)?.*(?:Bus|Autobus|Zug|Strecke|Route|Tratta) +(.*)\n.*(?:Direction|à destination de|Kierunek|richting|Richtung|Direzione) (.*)\n(?:.*(?:Operated|Betrieben|Uitgevoerd|Effettuata).*\n)?(.*)\n(?:[ ]+(.*?)(?:\n|,\n +(.*)\n))?/);
+        const stations = stationColumn.substr(idxStations).match(/(.*)\n[ ]+(.*)(?:\n|,\n  +(.*)\n)(?:.*(?:NOTE:|Wagennummerierung|platform|The regional part).(?:.*\n)+)?.*(?:Bus|Autobus|Zug|Strecke|Route|Tratta) +(.*)\n.*(?:Direction|à destination de|Kierunek|richting|Richtung|Direzione) (.*)\n(?:.*(?:Operated|Betrieben|Uitgevoerd|Effettuata).*\n)?(.*)\n(?:[ ]+(.*?)(?:\n|,\n +(.*)\n))?/);
         if (!times || !stations) {
             break;
         }
